@@ -21,7 +21,7 @@ gi.require_version('XApp', '1.0')
 from gi.repository import Gtk, Gdk, Gio, XApp, GdkPixbuf
 
 #   3. Local application/library specific imports.
-from common import _async, idle, WebAppManager, download_favicon, ICONS_DIR, BROWSER_TYPE_FIREFOX, BROWSER_TYPE_FIREFOX_FLATPAK, BROWSER_TYPE_FIREFOX_SNAP
+from common import _async, idle, WebAppManager, download_favicon, ICONS_DIR, BROWSER_TYPE_FIREFOX, BROWSER_TYPE_FIREFOX_FLATPAK, BROWSER_TYPE_ZEN_FLATPAK, BROWSER_TYPE_FIREFOX_SNAP
 
 setproctitle.setproctitle("webapp-manager")
 
@@ -89,6 +89,7 @@ class WebAppManagerWindow:
         self.run_button = self.builder.get_object("run_button")
         self.ok_button = self.builder.get_object("ok_button")
         self.name_entry = self.builder.get_object("name_entry")
+        self.desc_entry = self.builder.get_object("desc_entry")
         self.url_entry = self.builder.get_object("url_entry")
         self.url_label = self.builder.get_object("url_label")
         self.customparameters_entry = self.builder.get_object("customparameters_entry")
@@ -238,17 +239,13 @@ class WebAppManagerWindow:
         dlg.set_program_name(_("Web Apps"))
         dlg.set_comments(_("Run websites as if they were apps"))
         try:
-            h = open('/usr/share/licenses/spdx/GPL-3.0-or-later.txt', encoding="utf-8")
-            s = h.readlines()
-            gpl = ""
-            for line in s:
-                gpl += line
-            h.close()
+            with open('/usr/share/common-licenses/GPL', encoding="utf-8") as h:
+                gpl = h.read()
             dlg.set_license(gpl)
         except Exception as e:
             print(e)
 
-        dlg.set_version("1.4.0")
+        dlg.set_version("1.4.2")
         dlg.set_icon_name("webapp-manager")
         dlg.set_logo_icon_name("webapp-manager")
         dlg.set_website("https://www.github.com/linuxmint/webapp-manager")
@@ -313,6 +310,7 @@ class WebAppManagerWindow:
         category = self.category_combo.get_model()[self.category_combo.get_active()][CATEGORY_ID]
         browser = self.browser_combo.get_model()[self.browser_combo.get_active()][BROWSER_OBJ]
         name = self.name_entry.get_text()
+        desc = self.desc_entry.get_text().strip()
         url = self.get_url()
         isolate_profile = self.isolated_switch.get_active()
         navbar = self.navbar_switch.get_active()
@@ -326,15 +324,16 @@ class WebAppManagerWindow:
             shutil.copyfile(icon, new_path)
             icon = new_path
         if self.edit_mode:
-            self.manager.edit_webapp(self.selected_webapp.path, name, browser, url, icon, category, custom_parameters, self.selected_webapp.codename, isolate_profile, navbar, privatewindow)
+            self.manager.edit_webapp(self.selected_webapp.path, name, desc, browser, url, icon, category, custom_parameters, self.selected_webapp.codename, isolate_profile, navbar, privatewindow)
             self.load_webapps()
         else:
-            self.manager.create_webapp(name, url, icon, category, browser, custom_parameters, isolate_profile, navbar,
+            self.manager.create_webapp(name, desc, url, icon, category, browser, custom_parameters, isolate_profile, navbar,
                                        privatewindow)
             self.load_webapps()
 
     def on_add_button(self, widget):
         self.name_entry.set_text("")
+        self.desc_entry.set_text("")
         self.url_entry.set_text("")
         self.customparameters_entry.set_text("")
         self.icon_chooser.set_icon("webapp-manager")
@@ -355,6 +354,7 @@ class WebAppManagerWindow:
     def on_edit_button(self, widget):
         if self.selected_webapp is not None:
             self.name_entry.set_text(self.selected_webapp.name)
+            self.desc_entry.set_text(self.selected_webapp.desc)
             self.icon_chooser.set_icon(self.selected_webapp.icon)
             self.url_entry.set_text(self.selected_webapp.url)
             self.customparameters_entry.set_text(self.selected_webapp.custom_parameters)
@@ -452,7 +452,7 @@ class WebAppManagerWindow:
 
     def show_hide_browser_widgets(self):
         browser = self.browser_combo.get_model()[self.browser_combo.get_active()][BROWSER_OBJ]
-        if browser.browser_type in [BROWSER_TYPE_FIREFOX, BROWSER_TYPE_FIREFOX_FLATPAK, BROWSER_TYPE_FIREFOX_SNAP]:
+        if browser.browser_type in [BROWSER_TYPE_FIREFOX, BROWSER_TYPE_FIREFOX_FLATPAK, BROWSER_TYPE_FIREFOX_SNAP, BROWSER_TYPE_ZEN_FLATPAK]:
             self.isolated_label.hide()
             self.isolated_switch.hide()
             self.navbar_label.show()
